#!/usr/bin/env bash

_new_app() {
  run $ABRA app new \
    --no-input \
    --server "$TEST_SERVER" \
    --domain "$TEST_APP_DOMAIN" \
    --secrets \
    "$TEST_RECIPE"
  assert_success
  assert_exists "$ABRA_DIR/servers/$TEST_SERVER/$TEST_APP_DOMAIN.env"
}

_deploy_app() {
  run $ABRA app deploy --no-input "$TEST_APP_DOMAIN"
  assert_success

  run $ABRA app ls --server "$TEST_SERVER" --status
  assert_success
  assert_output --partial "$TEST_APP_DOMAIN"
  assert_output --partial 'deployed'
}

_undeploy_app() {
  run $ABRA app undeploy --no-input "$TEST_APP_DOMAIN"
  assert_success

  run $ABRA app ls --server "$TEST_SERVER" --status
  assert_success
  assert_output --partial "$TEST_APP_DOMAIN"
  assert_output --partial 'unknown'
}

_rm_app() {
  # NOTE(d1): not asserting outcomes on teardown here since some might fail
  # depending on what the test created. all commands run through anyway
  if [[ -f "$ABRA_DIR/servers/$TEST_SERVER/$TEST_APP_DOMAIN.env" ]]; then
    run $ABRA app undeploy --no-input "$TEST_APP_DOMAIN"
    run $ABRA app secret remove --all --no-input "$TEST_APP_DOMAIN"
    run $ABRA app volume remove --no-input "$TEST_APP_DOMAIN"
    run $ABRA app remove --no-input "$TEST_APP_DOMAIN"
  fi
}

_reset_app(){
  run rm -rf "$ABRA_DIR/servers/$TEST_SERVER/$TEST_APP_DOMAIN.env"
  assert_success
  assert_not_exists "$ABRA_DIR/servers/$TEST_SERVER/$TEST_APP_DOMAIN.env"

  run $ABRA app new \
    --no-input \
    --server "$TEST_SERVER" \
    --domain "$TEST_APP_DOMAIN" \
    "$TEST_RECIPE"
  assert_success
  assert_exists "$ABRA_DIR/servers/$TEST_SERVER/$TEST_APP_DOMAIN.env"
}
